import { HttpClient } from '@angular/common/http';
import { Component, Inject, OnInit } from '@angular/core';
import { MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-create-image',
  templateUrl: './create-image.component.html',
  styleUrls: ['./create-image.component.css']
})
export class CreateImageComponent implements OnInit {
  name: string = '';
  downloads: any[] = [];
  selectedDownload: any;

  constructor(
    private toastService: ToastrService,
    private http: HttpClient,
    public dialogRef: MatDialogRef<CreateImageComponent>,
    @Inject(MAT_DIALOG_DATA) public data: any
  ) { }

  ngOnInit(): void {
    this.fetchDownloads();
  }

  fetchDownloads(): void {
    this.http.get('http://127.0.0.1:8080/og-lives/server/get-isos?page=1&itemsPerPage=30')
      .subscribe({
        next: (response: any) => {
          this.downloads = response.data.downloads;
        },
        error: (error) => {
          console.error('Error fetching downloads:', error);
          this.toastService.error('Error fetching iso files');
        }
      });

  }

  onNoClick(): void {
    this.dialogRef.close();
  }

  addOgLive(): void {
    const payload = {
      name: this.name,
      downloadUrl: this.selectedDownload.URL
    };

    this.http.post('http://127.0.0.1:8080/og-lives', payload)
      .subscribe({
        next: (response) => {
          console.log('Success:', response);
          this.toastService.success('Image created successfully');
          this.dialogRef.close();
        },
        error: (error) => {
          console.error('Error:', error);
          this.toastService.error('Error creating image');
        }
      });
  }
}
