import { HttpClient } from '@angular/common/http';
import { Component, Inject } from '@angular/core';

import { ToastrService } from 'ngx-toastr';
import { MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';

@Component({
  selector: 'app-create-pxe-boot-file',
  templateUrl: './create-pxe-boot-file.component.html',
  styleUrls: ['./create-pxe-boot-file.component.css']
})
export class CreatePxeBootFileComponent {
  pxeTemplates: any[] = [];
  selectedPxeTemplate: string | undefined;
  clientes: string[] = [];
  selectedElements: any;

  constructor(
    private toastService: ToastrService,
    private http: HttpClient,
    private dialogRef: MatDialogRef<CreatePxeBootFileComponent>,
    @Inject(MAT_DIALOG_DATA) public data: string[]
  ) {}

  ngOnInit(): void {
    this.selectedElements = this.data;
    this.clientes = this.selectedElements.map((client: { uuid: any; }) => `/clients/${client.uuid}`);
    this.loadPxeTemplates();
  }

  getClientesNames(): string {
    return this.selectedElements.map((client: { name: any; }) => client.name).join(', ');
  }

  loadPxeTemplates(): void {
    this.http.get('http://127.0.0.1:8080/pxe-templates?page=1&itemsPerPage=30')
      .subscribe((response: any) => {
        this.pxeTemplates = response['hydra:member'];
      }, error => {
        console.error('Error fetching PXE templates:', error);
      });
  }

  onCancel(): void {
    this.dialogRef.close();
  }

  onAdd(): void {
    if (this.selectedPxeTemplate) {
      const payload = {
        template: `/pxe-templates/${this.selectedPxeTemplate}`,
        clients: this.clientes
      };
      console.log('Payload FINAAAL:', payload);
      this.http.post('http://127.0.0.1:8080/pxe-boot-files', payload)
        .subscribe({
          next: response => {
            this.toastService.success('PXE asignado con éxito');
            this.dialogRef.close();  
          },
          error: error => {
            this.toastService.error('Error enviando el payload', error);
          }
        });
    } else {
      console.error('No se ha seleccionado ninguna plantilla PXE');
      this.toastService.error('No se ha seleccionado ninguna plantilla PXE');
    }
  }
}
