import { Component } from '@angular/core';
import {MatTableDataSource} from "@angular/material/table";
import {MatDialog} from "@angular/material/dialog";
import {HttpClient} from "@angular/common/http";
import { CreatePxeTemplateComponent } from '../pxe/pxe/create-pxeTemplate/create-pxe-template/create-pxe-template.component';
import { EditPxeTemplateComponent } from '../pxe/pxe/edit-pxe-template/edit-pxe-template.component';
import {PageEvent} from "@angular/material/paginator";

@Component({
  selector: 'app-pxe-boot-files',
  templateUrl: './pxe-boot-files.component.html',
  styleUrl: './pxe-boot-files.component.css'
})
export class PxeBootFilesComponent {
  pxeTemplates: any[] = []; // Inicializa el array de plantillas
  currentPage: number = 1;
  dataSource = new MatTableDataSource<any>();
  length: number = 0;
  itemsPerPage: number = 10;
  page: number = 1;
  pageSizeOptions: number[] = [5, 10, 20, 40, 100];
  selectedElements: string[] = [];
  columns = [
    {
      columnDef: 'id',
      header: 'ID',
      cell: (user: any) => `${user.id}`
    },
    {
      columnDef: 'name',
      header: 'Nombre de la plantilla',
      cell: (user: any) => `${user.name}`
    },
    {
      columnDef: 'createdAt',
      header: 'Fecha de creación',
      cell: (user: any) => `${user.createdAt}`
    }
  ];
  displayedColumns = [...this.columns.map(column => column.columnDef), 'actions'];

  private apiUrl = 'http://127.0.0.1:8080/pxe-boot-files';

  constructor(public dialog: MatDialog, private http: HttpClient) { }

  ngOnInit(): void {
    this.loadPxeTemplates();
  }

  loadPxeTemplates(): void {
    this.http.get<any>(`${this.apiUrl}?page=1&itemsPerPage=${this.itemsPerPage}`).subscribe({
      next: (response) => {
        this.dataSource.data = response['hydra:member'];
        this.length = response['hydra:totalItems'];
        console.log('Plantillas PXE cargadas:', this.pxeTemplates);
      },
      error: error => {
        console.error('Error al cargar plantillas PXE:', error);
      }
    });
  }

  addPxeTemplate() {
    const dialogRef = this.dialog.open(CreatePxeTemplateComponent, {
    });

    dialogRef.afterClosed().subscribe(() => {
      this.loadPxeTemplates();
    });
  }

  showPxeInfo(template: any) {

  }

  toggleAction(image: any, action:string): void {
    switch (action) {
      case 'create':
        this.http.post(`${this.apiUrl}/server/${image.uuid}/post`, {}).subscribe({
          next: () => {
            console.log('Plantilla cambiada');
            this.loadPxeTemplates();
          },
          error: (error) => {
            console.error('Error al cambiar la imagen:', error);
          }
        });
        break;
      case 'delete':
        this.http.post(`${this.apiUrl}/server/${image.uuid}/delete`, {}).subscribe({
          next: () => {
            console.log('Plantilla cambiada');
            this.loadPxeTemplates();
          },
          error: (error) => {
            console.error('Error al cambiar la imagen:', error);
          }
        });
        break;
      default:
        console.error('Acción no soportada:', action);
        break;
    }
  }

  deletePxeTemplate(uuid: string) {
    // Lógica para eliminar una plantilla
  }

  editPxeTemplate(template: any) {
    const dialogRef = this.dialog.open(EditPxeTemplateComponent, {
      data: template
    });

    dialogRef.afterClosed().subscribe(() => {
      this.loadPxeTemplates();
    });
  }

  applyFilter() {
    this.http.get<any>(`${this.apiUrl}?page=${this.page}&itemsPerPage=${this.itemsPerPage}`).subscribe({
      next: (response) => {
        this.dataSource.data = response['hydra:member'];
        this.length = response['hydra:totalItems'];
      },
      error: (error) => {
        console.error('Error al cargar las imágenes:', error);
      }
    });
  }

  onPageChange(event: PageEvent) {
    this.page = event.pageIndex;
    this.itemsPerPage = event.pageSize;
    this.applyFilter();
  }

}
