import { HttpClient } from '@angular/common/http';
import { Component, Inject, OnInit } from '@angular/core';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';

@Component({
  selector: 'app-edit-pxe-template',
  templateUrl: './edit-pxe-template.component.html',
  styleUrls: ['./edit-pxe-template.component.css'] 
})
export class EditPxeTemplateComponent implements OnInit {
  templateForm!: FormGroup;

  constructor(
    private fb: FormBuilder,
    private http: HttpClient,
    public dialogRef: MatDialogRef<EditPxeTemplateComponent>,
    @Inject(MAT_DIALOG_DATA) public data: any
  ) {}

  ngOnInit(): void {
    console.log(this.data);
    this.templateForm = this.fb.group({
      name: [this.data.name || '', Validators.required],
      templateContent: [this.data.templateContent || '', Validators.required]
    });
  }

  onCreate(): void {
    if (this.templateForm.valid) {
      const updatedTemplate = {
        name: this.templateForm.value.name,
        templateContent: this.templateForm.value.templateContent
      };

      this.http.patch(`http://127.0.0.1:8080/pxe-templates/${this.data.uuid}`, updatedTemplate)
        .subscribe({
          next: () => {
            console.log('Plantilla actualizada correctamente');
            this.dialogRef.close(true); 
          },
          error: (error) => {
            console.error('Error al actualizar la plantilla:', error); 
          }
        });
    }
  }

  onCancel(): void {
    this.dialogRef.close(); 
  }
}
