import { HttpClient } from '@angular/common/http';
import { Component } from '@angular/core';
import { CreatePxeTemplateComponent } from './create-pxeTemplate/create-pxe-template/create-pxe-template.component';
import { MatDialog } from '@angular/material/dialog';
import { EditPxeTemplateComponent } from './edit-pxe-template/edit-pxe-template.component';
import {MatTableDataSource} from "@angular/material/table";
import {PageEvent} from "@angular/material/paginator";
import {ToastrService} from "ngx-toastr";
import {DatePipe} from "@angular/common";
import { DeletePxeTemplateComponent } from './delete-pxeTemplate/delete-pxe-template/delete-pxe-template.component';

@Component({
  selector: 'app-pxe',
  templateUrl: './pxe.component.html',
  styleUrl: './pxe.component.css'
})
export class PxeComponent {
  pxeTemplates: any[] = []; 
  currentPage: number = 1;
  dataSource = new MatTableDataSource<any>();
  length: number = 0;
  itemsPerPage: number = 10;
  page: number = 1;
  pageSizeOptions: number[] = [5, 10, 20, 40, 100];
  selectedElements: string[] = [];
  alertMessage: string | null = null;
  datePipe: DatePipe = new DatePipe('es-ES');
  selectedItem: any = null;
  previewContent: any | null = null;
  columns = [
    {
      columnDef: 'id',
      header: 'ID',
      cell: (user: any) => `${user.id}`
    },
    {
      columnDef: 'name',
      header: 'Nombre de la plantilla',
      cell: (user: any) => `${user.name}`
    },
    {
      columnDef: 'synchronized',
      header: 'Creado en ogBoot',
      cell: (user: any) => `${user.synchronized}`
    },
    {
      columnDef: 'createdAt',
      header: 'Fecha de creación',
      cell: (user: any) => `${this.datePipe.transform(user.createdAt, 'dd/MM/yyyy hh:mm:ss')}`
    }
  ];
  displayedColumns = [...this.columns.map(column => column.columnDef), 'actions'];

  private apiUrl = 'http://127.0.0.1:8080/pxe-templates';

  constructor(
    public dialog: MatDialog,
    private http: HttpClient,
    private toastService: ToastrService,
  ) { }

  ngOnInit(): void {
    this.loadPxeTemplates();
    this.loadAlert()
  }

  loadPxeTemplates(): void {
    this.http.get<any>(`${this.apiUrl}?page=1&itemsPerPage=${this.itemsPerPage}`).subscribe({
      next: (response) => {
        this.dataSource.data = response['hydra:member'];
        this.length = response['hydra:totalItems'];
        console.log('Plantillas PXE cargadas:', this.pxeTemplates);
      },
      error: error => {
        console.error('Error al cargar plantillas PXE:', error);
      }
    });
  }

  addPxeTemplate() {
    const dialogRef = this.dialog.open(CreatePxeTemplateComponent, {
      width: '600px'
    });

    dialogRef.afterClosed().subscribe(() => {
      this.loadPxeTemplates();
    });
  }

  showPxeInfo(template: any) {
    this.selectedItem = template;

    this.previewContent = template.templateContent;
  }

  toggleAction(image: any, action:string): void {
    switch (action) {
      case 'create':
        this.http.post(`${this.apiUrl}/server/${image.uuid}/post`, {}).subscribe({
          next: (response) => {
            this.loadPxeTemplates();
            // @ts-ignore
            this.toastService.success(response.message);
          },
          error: (error) => {
            this.toastService.error(error.error.error);
          }
        });
        break;
      case 'delete':
        this.http.post(`${this.apiUrl}/server/${image.uuid}/delete`, {}).subscribe({
          next: () => {
            console.log('Plantilla cambiada');
            this.loadPxeTemplates();
          },
          error: (error) => {
            console.error('Error al cambiar la imagen:', error);
          }
        });
        break;
      default:
        console.error('Acción no soportada:', action);
        break;
    }
  }

  deletePxeTemplate(template: any) {
    // Lógica para eliminar una plantilla
      const dialogRef = this.dialog.open(DeletePxeTemplateComponent, {
        width: '300px'
      });

      console.log('Eliminando pxe:', template.uuid);
    
      dialogRef.afterClosed().subscribe(result => {
        if (result) {
          this.http.delete(`http://127.0.0.1:8080/pxe-templates/${template.uuid}`).subscribe({
            next: () => {
              console.log('pxe eliminado');
              this.toastService.success('PXE deleted successfully');
              this.loadPxeTemplates();
            },
            error: (error) => {
              console.error('Error al eliminar la pxe:', error);
            }
          });
        } else {
          console.log('Eliminación de pxe cancelada');
        }
      }); 
    
  }

  editPxeTemplate(template: any) {
    const dialogRef = this.dialog.open(EditPxeTemplateComponent, {
      data: template
    });

    dialogRef.afterClosed().subscribe(() => {
      this.loadPxeTemplates();
    });
  }

  applyFilter() {
    this.http.get<any>(`${this.apiUrl}?page=${this.page}&itemsPerPage=${this.itemsPerPage}`).subscribe({
      next: (response) => {
        this.dataSource.data = response['hydra:member'];
        this.length = response['hydra:totalItems'];
      },
      error: (error) => {
        console.error('Error al cargar las imágenes:', error);
      }
    });
  }

  onPageChange(event: PageEvent) {
    this.page = event.pageIndex;
    this.itemsPerPage = event.pageSize;
    this.applyFilter();
  }

  loadAlert() {
    this.http.get(`${this.apiUrl}/server/get-collection`)
      .subscribe(response => {
        // @ts-ignore
        this.alertMessage = response.templates.length
      }, error => {
        console.error('Error al cargar la información del alert', error);
      });
  }

  getIcon(): { name: string, color: string } {
    if (Number(this.alertMessage) === this.length) {
      return { name: 'check_circle', color: 'green' }; // Icono de check verde
    } else {
      return { name: 'cancel', color: 'red' }; // Icono de cruz roja
    }
  }

}
